"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const autoBind = require("auto-bind");
const graphql_codegen_visitor_plugin_common_1 = require("graphql-codegen-visitor-plugin-common");
const graphql_codegen_typescript_1 = require("graphql-codegen-typescript");
class TypeScriptResolversVisitor extends graphql_codegen_visitor_plugin_common_1.BaseResolversVisitor {
    constructor(pluginConfig, schema) {
        super(pluginConfig, {
            avoidOptionals: pluginConfig.avoidOptionals || false,
            immutableTypes: pluginConfig.immutableTypes || false
        }, schema);
        autoBind(this);
        this.setVariablesTransformer(new graphql_codegen_typescript_1.TypeScriptOperationVariablesToObject(this.config.scalars, this.convertName, this.config.avoidOptionals, this.config.immutableTypes));
    }
    formatRootResolver(schemaTypeName, resolverType) {
        return `${schemaTypeName}?: ${resolverType},`;
    }
    getRootResolver() {
        return super
            .getRootResolver()
            .replace('};', '} & { [typeName: string] : { [ fieldName: string ]: ( Resolver<any, any, Context, any> | SubscriptionResolver<any, any, Context, any> ) } };');
    }
    getAllDirectiveResolvers() {
        return super
            .getAllDirectiveResolvers()
            .replace('};', '} & { [directiveName: string]: DirectiveResolverFn<any, any, Context, any> };');
    }
    clearOptional(str) {
        if (str.startsWith('Maybe')) {
            return str.replace(/Maybe<(.*?)>/, '$1');
        }
        return str;
    }
    ListType(node) {
        return `Maybe<${super.ListType(node)}>`;
    }
    wrapWithListType(str) {
        return `${this.config.immutableTypes ? 'ReadonlyArray' : 'Array'}<${str}>`;
    }
    NamedType(node) {
        return `Maybe<${super.NamedType(node)}>`;
    }
    NonNullType(node) {
        const baseValue = super.NonNullType(node);
        return this.clearOptional(baseValue);
    }
}
exports.TypeScriptResolversVisitor = TypeScriptResolversVisitor;
//# sourceMappingURL=visitor.js.map